[−][src]Struct psyche_utils::bucket_strainer::Bucket
Bucket strainer bucket that contains rule that scores items and collection of items that fallen into it on processing phase.
Fields
acceptable_score_treshold: ScalarMethods
impl<T> Bucket<T> where
T: Clone, [src]
T: Clone,
pub fn new(id: String, rule: Box<dyn Rule<T>>) -> Self[src]
pub fn id(&self) -> &str[src]
pub fn items(&self) -> &[T][src]
pub fn rule(&self) -> &Box<dyn Rule<T>>[src]
pub fn replace_rule(&mut self, rule: Box<dyn Rule<T>>) -> Box<dyn Rule<T>>[src]